@@ -35,12 +35,12 @@ from botocore.paginate import Paginator as Boto3Paginator
 from .literals import ActionOwnerType
 from .type_defs import (
     ActionExecutionFilterTypeDef,
-    ListActionExecutionsOutputTypeDef,
-    ListActionTypesOutputTypeDef,
-    ListPipelineExecutionsOutputTypeDef,
-    ListPipelinesOutputTypeDef,
-    ListTagsForResourceOutputTypeDef,
-    ListWebhooksOutputTypeDef,
+    ListActionExecutionsOutputResponseTypeDef,
+    ListActionTypesOutputResponseTypeDef,
+    ListPipelineExecutionsOutputResponseTypeDef,
+    ListPipelinesOutputResponseTypeDef,
+    ListTagsForResourceOutputResponseTypeDef,
+    ListWebhooksOutputResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -56,25 +56,27 @@ __all__ = (
 
 class ListActionExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
     """
 
     def paginate(
         self,
         *,
         pipelineName: str,
-        filter: ActionExecutionFilterTypeDef = None,
+        filter: "ActionExecutionFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListActionExecutionsOutputTypeDef]:
+    ) -> Iterator[ListActionExecutionsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
 
 class ListActionTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
     """
 
     def paginate(
@@ -83,64 +85,68 @@ class ListActionTypesPaginator(Boto3Paginator):
         actionOwnerFilter: ActionOwnerType = None,
         regionFilter: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListActionTypesOutputTypeDef]:
+    ) -> Iterator[ListActionTypesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
 
 class ListPipelineExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
     """
 
     def paginate(
         self, *, pipelineName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPipelineExecutionsOutputTypeDef]:
+    ) -> Iterator[ListPipelineExecutionsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPipelinesOutputTypeDef]:
+    ) -> Iterator[ListPipelinesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, *, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTagsForResourceOutputTypeDef]:
+    ) -> Iterator[ListTagsForResourceOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
 
 class ListWebhooksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListWebhooksOutputTypeDef]:
+    ) -> Iterator[ListWebhooksOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
